Changes:
========

0.7.2
*****

Bug fixes:

* Arguments now work correctly (thanks to Martin Mahner).
* Fixed a bug in the regex that would split passed values incorrectly occasionally.

New:

* START_TAG and END_TAG can now be controlled via settings.


0.7.1
*****

* Includes fixes from Jannis Leidel so it actually works on Pypi now. Thanks Jannis!


0.7
***

* Initial public release